#!/usr/bin/env bash

dev="eth+"

if [ "$(cat /proc/sys/net/ipv4/ip_forward)" != 1 ]; then
	sudo sh -c "echo 1 > /proc/sys/net/ipv4/ip_forward"
	sudo iptables -t nat -A POSTROUTING -o "$dev" -j MASQUERADE
fi

logdir="current_log"
mkdir -p "$logdir"

term() {
  title="$2"
  if [ -z "$title" ]; then
    title="$(basename $@)"
  fi
  exec urxvt -title "CN:$title" -e sh -c "export LD_LIBRARY_PATH=/usr/local/lib; $1; echo; while true; do echo 'q Enter to close'; read q_to_close; if [ \"x\$q_to_close\" = xq ]; then break; fi; done"
}

sudo tcpdump -i eth0 -n -w current_log/eth0.single.pcap -U not port 22 &
sudo tcpdump -i lo -n -w current_log/lo.single.pcap -U not port 22 &

sgsn="osmo-sgsn -c osmo-sgsn.cfg"
ggsn="sudo LD_LIBRARY_PATH=/usr/local/lib ggsn -f -c ggsn.conf"
nitb="gdb -ex run --args osmo-nitb -c osmo-nitb.cfg"

term "$ggsn" GGSN &
sleep .2
term "$sgsn" SGSN &
sleep .2
term "$nitb" NITB &

ssh bts rm /tmp/bts.log /tmp/pcu.log
ssh bts neels/run_remote.sh &

echo enter to close
read enter_to_close
echo closing...

ssh bts neels/stop_remote.sh

kill %1 %2 %3 %4 %5
killall osmo-nitb
killall osmo-sgsn
killall ggsn

sudo killall tcpdump

cp \
	ggsn.conf \
	osmo-nitb.cfg \
	osmo-sgsn.cfg \
	"$logdir"

echo
echo enter name to save log
read log_name
if [ -n "$log_name" ]; then
  newlogdir="log/$log_name"
  scp "bts:/tmp/{bts,pcu}.log" "bts:neels/osmo-{bts,pcu}.cfg" "$logdir"
else
  newlogdir="autolog/log_$(date +%Y-%m-%d_%H-%M-%S)"
fi
mkdir -p "$(dirname "$newlogdir")"

mergecap -w "$logdir/trace.pcap" "$logdir/"*.single.pcap
#rm "$logdir/"*.single.pcap

if [ -x "$newlogdir" ]; then
  echo "already exists, move it manually: $newlogdir"
else
  echo mv "$logdir" "$newlogdir"
  mv "$logdir" "$newlogdir"
  mkdir -p "$logdir"
  logdir="$newlogdir"
fi
rm lastlog
ln -s "$logdir" lastlog
